@@ -59,6 +59,25 @@ def date_range_params(period_config, comparison, period, reference_date):
     elif period_config == "lmtd":
         start_date = (today + relativedelta(months=-1)).strftime("%Y-%m-01")
         end_date = (today + relativedelta(months=-1)).strftime("%Y-%m-%d")
+
+    elif period_config == "yesterday":
+        start_date = (today + relativedelta(days=-1)).strftime("%Y-%m-%d")
+        end_date = today.strftime("%Y-%m-%d")
+
+    elif period_config == "day_before_yesterday":
+        start_date = (today + relativedelta(days=-2)).strftime("%Y-%m-%d")
+        end_date = (today + relativedelta(days=-1)).strftime("%Y-%m-%d")
+
+    elif period_config == "l7d":
+        start_date = (today + relativedelta(days=-7)).strftime("%Y-%m-%d")
+        end_date = today.strftime("%Y-%m-%d")
+
+    elif period_config == "previous_l7d":
+        start_date = (today + relativedelta(days=-14)).strftime("%Y-%m-%d")
+        end_date = (today + relativedelta(days=-7)).strftime("%Y-%m-%d")
+
+
+
     else:
         return {}
     if comparison:
@@ -76,7 +95,9 @@ class DataSource:
     def __init__(self, dbstream: DBStream, path_to_datasource_folder,
                  schema_prefix=None,
                  layer_type='datasource',
-                 loader_function=None):
+                 loader_function=None,
+                 jinja_env=None,
+                 update_schema_name_with_env=True):
         """
 
         :param dbstream:
@@ -87,7 +108,8 @@ class DataSource:
         self.schema_prefix = schema_prefix
         self.layer_type = layer_type
         self.loader_function = loader_function
-        self.jinja_env = jinja2.Environment()
+        self.jinja_env = jinja2.Environment() if jinja_env is None else jinja_env
+        self.update_schema_name_with_env = update_schema_name_with_env
 
     def _build_folder_path(self, layer_name):
         return self.path_to_datasource_folder + 'layers/' + layer_name + "/"
@@ -190,6 +212,15 @@ class DataSource:
             )
             )
 
+        if query_config.get("daterange"):
+            dict_params.update(date_range_params(
+                period_config=query_config.get("daterange"),
+                comparison=False,
+                period=None,
+                reference_date=reference_date
+            )
+            )
+
         if query_config.get("period_comparison"):
             dict_params.update(date_range_params(
                 period_config=query_config.get("period_comparison"),
@@ -250,11 +281,16 @@ class DataSource:
             result_dict[layer_name][query]["started_at"] = str(datetime.datetime.now())
             log_info("Layer: %s | Query started: %s | Environment: %s" % (layer_name, query, environment))
             query_config = queries_config[query]
+            schema_name_filled_query = schema_name
+            if self.update_schema_name_with_env:
+                schema_name_filled_query = schema_name if environment == 'production' else (
+                        schema_name + "_" + environment
+                )
             filled_query = self._filled_query(
                 query_config=query_config,
                 query=query,
                 folder_path=folder_path,
-                schema_name=schema_name if environment == 'production' else (schema_name + "_" + environment),
+                schema_name=schema_name_filled_query,
                 layer_name=layer_name,
                 environment=environment,
                 period=period,
